# Video Storage
Storage wie? --> Preis

https://cloud.google.com/storage/pricing-summary/
oder ein server?

lokal is doof, weil viel.


## Wieviel Platz braucht's?
```
$ ls -l --time-style=full-iso 2019-10-11_05-50-25.mkv
-rw-rw-r-- 1 felix felix 15921680 2019-10-11 05:53:00.159530225 +0200 2019-10-11_05-50-25.mkv
```

Video hat 300 MB / h.
Also grob 7GB / Tag.

Die hier hat 4 TB, also 4000 GB und kostet 100€.

https://www.heise.de/preisvergleich/western-digital-wd-blue-4tb-wd40ezrz-a1311454.html?hloc=at&hloc=de.

Wie lang kannste damit 24/7 aufnehmen?

4000 / 7 ~ 570 Tage
